==> icedtea-web-1.0.1.tar.gz: icedtea-web-1.0.1/plugin/icedteanp/java/sun/applet/PluginCallRequest.java <==
/* PluginCallRequest -- represent Java-to-JavaScript requests
   Copyright (C) 2008  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package sun.applet;

import java.security.AccessControlContext;
import java.security.ProtectionDomain;

// FIXME: for each type of request extend a new (anonymous?)
// PluginCallRequest.
public abstract class PluginCallRequest {
    String message;
    Long reference;
    PluginCallRequest next;
    boolean done = false;

    public PluginCallRequest(String message, Long reference) {
        this.message = message;
        this.reference = reference;
    }

    public String getMessage() {
        return this.message;
    }

    public boolean isDone() {
        return this.done;
    }

    public boolean setDone(boolean done) {
        return this.done = done;
    }

    public void setNext(PluginCallRequest next) {
        this.next = next;
    }

    public PluginCallRequest getNext() {
        return this.next;
    }

    /**
     * Returns whether the given message is serviceable by this object
     * 
     * @param message The message to service
     * @return boolean indicating if message is serviceable
     */
    public boolean serviceable(String message) {
        return message.contains("reference " + reference);
    }

    public abstract void parseReturn(String message);

    public abstract Object getObject();
}

==> icedtea-web_1.2.3.orig.tar.gz: icedtea-web-1.2.3/plugin/icedteanp/java/sun/applet/PluginCallRequest.java <==
/* PluginCallRequest -- represent Java-to-JavaScript requests
   Copyright (C) 2008  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package sun.applet;

// FIXME: for each type of request extend a new (anonymous?)
// PluginCallRequest.
public abstract class PluginCallRequest {
    private String message;
    private Long reference;
    private PluginCallRequest next;
    private boolean done = false;

    public PluginCallRequest(String message, Long reference) {
        this.message = message;
        this.reference = reference;
    }

    public String getMessage() {
        return this.message;
    }

    public boolean isDone() {
        return this.done;
    }

    public boolean setDone(boolean done) {
        return this.done = done;
    }

    public void setNext(PluginCallRequest next) {
        this.next = next;
    }

    public PluginCallRequest getNext() {
        return this.next;
    }

    /**
     * Returns whether the given message is serviceable by this object
     * 
     * @param message The message to service
     * @return boolean indicating if message is serviceable
     */
    public boolean serviceable(String message) {
        return message.contains("reference " + reference);
    }

    public abstract void parseReturn(String message);

    public abstract Object getObject();
}
